@@ -1,7 +1,8 @@
 /*
  *  Off-the-Record Messaging plugin for pidgin
- *  Copyright (C) 2004-2008  Ian Goldberg, Rob Smits,
- *                           Chris Alexander, Nikita Borisov
+ *  Copyright (C) 2004-2012  Ian Goldberg, Rob Smits,
+ *                           Chris Alexander, Willy Lew,
+ *                           Nikita Borisov
  *                           <otr@cypherpunks.ca>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -15,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,9 +105,11 @@ void otrg_dialog_notify_info(const char *accountname, const char *protocol,
  * username conversation.  Return 0 on success, non-0 on error (in which
  * case the message will be displayed inline as a received message). */
 int otrg_dialog_display_otr_message( const char *accountname,
-	const char *protocol, const char *username, const char *msg)
+	const char *protocol, const char *username, const char *msg,
+	int force_create)
 {
-    return ui_ops->display_otr_message(accountname, protocol, username, msg);
+    return ui_ops->display_otr_message(accountname, protocol, username, msg,
+	    force_create);
 }
 
 /* Put up a Please Wait dialog.  This dialog can not be cancelled.
@@ -153,9 +156,10 @@ void otrg_dialog_socialist_millionaires_q(ConnContext *context,
 }
 
 /* Update the status of an ongoing socialist millionaires protocol. */
-void otrg_dialog_update_smp(ConnContext *context, double progress_level)
+void otrg_dialog_update_smp(ConnContext *context, OtrlSMPEvent smp_event,
+	double progress_level)
 {
-    ui_ops->update_smp(context, progress_level);
+    ui_ops->update_smp(context, smp_event, progress_level);
 }
 
 /* Call this when a context transitions to ENCRYPTED. */
