@@ -42,6 +42,9 @@
 #ifdef ENABLE_NLS
 /* internationalisation header */
 #include <glib/gi18n-lib.h>
+#else
+#define _(x) (x)
+#define N_(x) (x)
 #endif
 
 /* purple-otr headers */
