@@ -1,7 +1,8 @@
 /*
  *  Off-the-Record Messaging plugin for pidgin
- *  Copyright (C) 2004-2008  Ian Goldberg, Rob Smits,
- *                           Chris Alexander, Nikita Borisov
+ *  Copyright (C) 2004-2012  Ian Goldberg, Rob Smits,
+ *                           Chris Alexander, Willy Lew,
+ *                           Lisa Du, Nikita Borisov
  *                           <otr@cypherpunks.ca>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -15,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __OTRG_OTR_PLUGIN_H__
@@ -28,15 +29,26 @@
 /* libotr headers */
 #include <libotr/context.h>
 #include <libotr/userstate.h>
+#include <libotr/instag.h>
 
 #define PRIVKEYFNAME "otr.private_key"
 #define STOREFNAME "otr.fingerprints"
+#define INSTAGFNAME "otr.instance_tags"
 #define MAXMSGSIZEFNAME "otr.max_message_size"
 
 extern PurplePlugin *otrg_plugin_handle;
 
 extern OtrlUserState otrg_plugin_userstate;
 
+/* Given a PurpleConversation, return the ConnContext corresponding to the
+ * selected instance tag. */
+ConnContext* otrg_plugin_conv_to_selected_context(PurpleConversation *conv,
+	int force_create);
+
+/* Given a PurpleConversation, return the selected instag. */
+otrl_instag_t otrg_plugin_conv_to_selected_instag(PurpleConversation *conv,
+	otrl_instag_t default_value);
+
 /* Send an IM from the given account to the given recipient.  Display an
  * error dialog if that account isn't currently logged in. */
 void otrg_plugin_inject_message(PurpleAccount *account, const char *recipient,
@@ -46,6 +58,10 @@ void otrg_plugin_inject_message(PurpleAccount *account, const char *recipient,
 void otrg_plugin_create_privkey(const char *accountname,
 	const char *protocol);
 
+/* Generate a instance tag for the given accountname/protocol */
+void otrg_plugin_create_instag(const char *accountname,
+	const char *protocol);
+
 /* Start the Socialist Millionaires' Protocol over the current connection,
  * using the given initial secret, and optionally a question to pass to
  * the buddy. */
@@ -76,7 +92,8 @@ void otrg_plugin_disconnect(ConnContext *context);
 void otrg_plugin_write_fingerprints(void);
 
 /* Find the ConnContext appropriate to a given PurpleConversation. */
-ConnContext *otrg_plugin_conv_to_context(PurpleConversation *conv);
+ConnContext *otrg_plugin_conv_to_context(PurpleConversation *conv,
+	otrl_instag_t their_instance, int force_create);
 
 /* Find the PurpleConversation appropriate to the given userinfo.  If
  * one doesn't yet exist, create it if force_create is true. */
@@ -88,6 +105,7 @@ PurpleConversation *otrg_plugin_userinfo_to_conv(const char *accountname,
 PurpleConversation *otrg_plugin_context_to_conv(ConnContext *context,
 	int force_create);
 
+
 typedef enum {
     TRUST_NOT_PRIVATE,
     TRUST_UNVERIFIED,
